==> pysyntect-0.1.2.tar.gz: CHANGELOG.md <==
## Version 0.1.2 (2020/04/21)

### Issues Closed

* [Issue 20](https://github.com/spyder-ide/pysyntect/issues/20) - Release v0.1.2

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 19](https://github.com/spyder-ide/pysyntect/pull/19) - PR: Standarize all names to ASCII, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 0.1.1 (2020/04/16)

### Issues Closed

* [Issue 18](https://github.com/spyder-ide/pysyntect/issues/18) - Release v0.1.1

In this release 1 issue was closed.

## Version 0.1.0 (2020/04/16)

### Issues Closed

* [Issue 17](https://github.com/spyder-ide/pysyntect/issues/17) - Release v0.1.0
* [Issue 15](https://github.com/spyder-ide/pysyntect/issues/15) - Improve README instructions ([PR 16](https://github.com/spyder-ide/pysyntect/pull/16) by [@andfoy](https://github.com/andfoy))
* [Issue 13](https://github.com/spyder-ide/pysyntect/issues/13) - Build and publish wheels using GitHub Actions ([PR 14](https://github.com/spyder-ide/pysyntect/pull/14) by [@andfoy](https://github.com/andfoy))
* [Issue 10](https://github.com/spyder-ide/pysyntect/issues/10) - Add tests ([PR 11](https://github.com/spyder-ide/pysyntect/pull/11) by [@andfoy](https://github.com/andfoy))
* [Issue 7](https://github.com/spyder-ide/pysyntect/issues/7) - Add language declarations ([PR 8](https://github.com/spyder-ide/pysyntect/pull/8) by [@andfoy](https://github.com/andfoy))
* [Issue 6](https://github.com/spyder-ide/pysyntect/issues/6) - Add compilation instructions ([PR 9](https://github.com/spyder-ide/pysyntect/pull/9) by [@andfoy](https://github.com/andfoy))
* [Issue 5](https://github.com/spyder-ide/pysyntect/issues/5) - Enable CIs ([PR 12](https://github.com/spyder-ide/pysyntect/pull/12) by [@andfoy](https://github.com/andfoy))
* [Issue 1](https://github.com/spyder-ide/pysyntect/issues/1) - Initialize this Repo ([PR 2](https://github.com/spyder-ide/pysyntect/pull/2) by [@andfoy](https://github.com/andfoy))

In this release 8 issues were closed.

### Pull Requests Merged

* [PR 16](https://github.com/spyder-ide/pysyntect/pull/16) - PR: Improve README instructions, by [@andfoy](https://github.com/andfoy) ([15](https://github.com/spyder-ide/pysyntect/issues/15))
* [PR 14](https://github.com/spyder-ide/pysyntect/pull/14) - PR: Add release pipeline, by [@andfoy](https://github.com/andfoy) ([13](https://github.com/spyder-ide/pysyntect/issues/13))
* [PR 12](https://github.com/spyder-ide/pysyntect/pull/12) - PR: Enable GitHub Actions, by [@andfoy](https://github.com/andfoy) ([5](https://github.com/spyder-ide/pysyntect/issues/5))
* [PR 11](https://github.com/spyder-ide/pysyntect/pull/11) - PR: Expose theme settings, refactor API and add tests, by [@andfoy](https://github.com/andfoy) ([10](https://github.com/spyder-ide/pysyntect/issues/10))
* [PR 9](https://github.com/spyder-ide/pysyntect/pull/9) - PR: Enable wheel distribution, add release instructions and licenses, by [@andfoy](https://github.com/andfoy) ([6](https://github.com/spyder-ide/pysyntect/issues/6))
* [PR 8](https://github.com/spyder-ide/pysyntect/pull/8) - PR: Add almost all existing language syntax files, by [@andfoy](https://github.com/andfoy) ([7](https://github.com/spyder-ide/pysyntect/issues/7))
* [PR 4](https://github.com/spyder-ide/pysyntect/pull/4) - PR: Fix some typos that prevent compilation, by [@andfoy](https://github.com/andfoy)
* [PR 3](https://github.com/spyder-ide/pysyntect/pull/3) - PR: Add basic wrapper example, by [@andfoy](https://github.com/andfoy)
* [PR 2](https://github.com/spyder-ide/pysyntect/pull/2) - PR: Add basic build project, by [@andfoy](https://github.com/andfoy) ([1](https://github.com/spyder-ide/pysyntect/issues/1))

In this release 9 pull requests were closed.

==> pysyntect-0.2.0.tar.gz: CHANGELOG.md <==
## Version 0.2.0 (2020/06/03)

### Issues Closed

* [Issue 22](https://github.com/spyder-ide/pysyntect/issues/22) - Release v0.2.0

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 21](https://github.com/spyder-ide/pysyntect/pull/21) - PR: Update syntect version to 4.2, PyO3 to 0.10.1, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 0.1.2 (2020/04/21)

### Issues Closed

* [Issue 20](https://github.com/spyder-ide/pysyntect/issues/20) - Release v0.1.2

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 19](https://github.com/spyder-ide/pysyntect/pull/19) - PR: Standarize all names to ASCII, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 0.1.1 (2020/04/16)

### Issues Closed

* [Issue 18](https://github.com/spyder-ide/pysyntect/issues/18) - Release v0.1.1

In this release 1 issue was closed.

## Version 0.1.0 (2020/04/16)

### Issues Closed

* [Issue 17](https://github.com/spyder-ide/pysyntect/issues/17) - Release v0.1.0
* [Issue 15](https://github.com/spyder-ide/pysyntect/issues/15) - Improve README instructions ([PR 16](https://github.com/spyder-ide/pysyntect/pull/16) by [@andfoy](https://github.com/andfoy))
* [Issue 13](https://github.com/spyder-ide/pysyntect/issues/13) - Build and publish wheels using GitHub Actions ([PR 14](https://github.com/spyder-ide/pysyntect/pull/14) by [@andfoy](https://github.com/andfoy))
* [Issue 10](https://github.com/spyder-ide/pysyntect/issues/10) - Add tests ([PR 11](https://github.com/spyder-ide/pysyntect/pull/11) by [@andfoy](https://github.com/andfoy))
* [Issue 7](https://github.com/spyder-ide/pysyntect/issues/7) - Add language declarations ([PR 8](https://github.com/spyder-ide/pysyntect/pull/8) by [@andfoy](https://github.com/andfoy))
* [Issue 6](https://github.com/spyder-ide/pysyntect/issues/6) - Add compilation instructions ([PR 9](https://github.com/spyder-ide/pysyntect/pull/9) by [@andfoy](https://github.com/andfoy))
* [Issue 5](https://github.com/spyder-ide/pysyntect/issues/5) - Enable CIs ([PR 12](https://github.com/spyder-ide/pysyntect/pull/12) by [@andfoy](https://github.com/andfoy))
* [Issue 1](https://github.com/spyder-ide/pysyntect/issues/1) - Initialize this Repo ([PR 2](https://github.com/spyder-ide/pysyntect/pull/2) by [@andfoy](https://github.com/andfoy))

In this release 8 issues were closed.

### Pull Requests Merged

* [PR 16](https://github.com/spyder-ide/pysyntect/pull/16) - PR: Improve README instructions, by [@andfoy](https://github.com/andfoy) ([15](https://github.com/spyder-ide/pysyntect/issues/15))
* [PR 14](https://github.com/spyder-ide/pysyntect/pull/14) - PR: Add release pipeline, by [@andfoy](https://github.com/andfoy) ([13](https://github.com/spyder-ide/pysyntect/issues/13))
* [PR 12](https://github.com/spyder-ide/pysyntect/pull/12) - PR: Enable GitHub Actions, by [@andfoy](https://github.com/andfoy) ([5](https://github.com/spyder-ide/pysyntect/issues/5))
* [PR 11](https://github.com/spyder-ide/pysyntect/pull/11) - PR: Expose theme settings, refactor API and add tests, by [@andfoy](https://github.com/andfoy) ([10](https://github.com/spyder-ide/pysyntect/issues/10))
* [PR 9](https://github.com/spyder-ide/pysyntect/pull/9) - PR: Enable wheel distribution, add release instructions and licenses, by [@andfoy](https://github.com/andfoy) ([6](https://github.com/spyder-ide/pysyntect/issues/6))
* [PR 8](https://github.com/spyder-ide/pysyntect/pull/8) - PR: Add almost all existing language syntax files, by [@andfoy](https://github.com/andfoy) ([7](https://github.com/spyder-ide/pysyntect/issues/7))
* [PR 4](https://github.com/spyder-ide/pysyntect/pull/4) - PR: Fix some typos that prevent compilation, by [@andfoy](https://github.com/andfoy)
* [PR 3](https://github.com/spyder-ide/pysyntect/pull/3) - PR: Add basic wrapper example, by [@andfoy](https://github.com/andfoy)
* [PR 2](https://github.com/spyder-ide/pysyntect/pull/2) - PR: Add basic build project, by [@andfoy](https://github.com/andfoy) ([1](https://github.com/spyder-ide/pysyntect/issues/1))

In this release 9 pull requests were closed.
